@@ -19,6 +19,7 @@ pub enum BackendType {
     Asdf,
     Cargo,
     Core,
+    Dotnet,
     Gem,
     Go,
     Npm,
@@ -44,6 +45,7 @@ impl BackendType {
             "asdf" => BackendType::Asdf,
             "cargo" => BackendType::Cargo,
             "core" => BackendType::Core,
+            "dotnet" => BackendType::Dotnet,
             "gem" => BackendType::Gem,
             "go" => BackendType::Go,
             "npm" => BackendType::Npm,
