@@ -1,4 +1,3 @@
-use std::fs::File;
 use std::io::Write;
 use std::path::Path;
 use std::time::Duration;
@@ -174,14 +173,16 @@ impl Client {
                 }
             }
 
-            file::create_dir_all(path.parent().unwrap())?;
-            let mut file = File::create(path)?;
+            let parent = path.parent().unwrap();
+            file::create_dir_all(parent)?;
+            let mut file = tempfile::NamedTempFile::with_prefix_in(path, parent)?;
             while let Some(chunk) = resp.chunk().await? {
                 file.write_all(&chunk)?;
                 if let Some(pr) = pr {
                     pr.inc(chunk.len() as u64);
                 }
             }
+            file.persist(path)?;
             Ok::<(), eyre::Error>(())
         })?;
         Ok(())
